#property copyright "Copyright @ 2013, Andrew Sumner"
#property link      "andrewsumner@yahoo.com"

#include <LibSSSRv5.mqh>

#define version "v1.0"
#define NL "\n"

//+------------------------------------------------------------------+
// expert initialization function                                   
//+------------------------------------------------------------------+
int init()
{
   // this isn't necessary if I'm happy with the default values, which
   // are the same as the indicator's.  The call below has some random
   // settings that I pulled off the top of my head ;)
   SSSR_Settings(1000, 1.2, true, true, 3, 5);

   // calling this when the EA starts to instantly get zones...
   SSSR_UpdateZones(false, Symbol(), Period());

   return(0);
}

//+------------------------------------------------------------------+
// expert deinitialization function                                
//+------------------------------------------------------------------+
int deinit()
{
   return(0);
}

//+------------------------------------------------------------------+
// expert start function                                            
//+------------------------------------------------------------------+
int start()
{
   // calling this with "true" as the first argument means
   // it doesn't do anything unless a new candle has formed 
   // since last time.  Call it with false and it'll recalculate
   // the zones, so don't do that every time through the start
   // function or your program will be very slow...
   SSSR_UpdateZones(true, Symbol(), Period());

   double res_hi=0, res_lo=0, sup_hi=0, sup_lo=0;
   int res_strength=0, sup_strength=0;
   int sup_zone, res_zone;

   // finding the support & resistance zones closest to the bid price
   res_zone = SSSR_FindZoneV2(SSSR_UP, true, Bid, res_hi, res_lo, res_strength);
   sup_zone = SSSR_FindZoneV2(SSSR_DN, true, Bid, sup_hi, sup_lo, sup_strength);

   string CommentStr = "\n\n";

   // get details of the zones and print them to the screen
   if (res_zone >= 0)
      CommentStr = CommentStr + "Resistance: "+DoubleToStr(res_hi, Digits)+"/"+DoubleToStr(res_lo,Digits)+" "+res_strength+", ";
   else
      CommentStr = CommentStr + "No Resistance Found, ";

   if (sup_zone >= 0)
      CommentStr = CommentStr + "Support: "+DoubleToStr(sup_hi, Digits)+"/"+DoubleToStr(sup_lo,Digits)+" "+sup_strength;
   else
      CommentStr = CommentStr + "No Support Found.";

   Comment(CommentStr);

   Sleep(150);
}


